.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

canary user's guide
===================

.. toctree::
   :caption: Getting started
   :maxdepth: 1

   about
   installing
   getting-help
   getting-started

.. toctree::
   :caption: Basics and usage
   :maxdepth: 2

   basics
   usage

.. toctree::
   :caption: Configuration
   :maxdepth: 2

   configuration

.. toctree::
   :caption: Creating reports
   :maxdepth: 2

   reporting

.. toctree::
   :caption: Extending canary through plugins
   :maxdepth: 2

   extending

.. toctree::
   :caption: Commands and directives
   :maxdepth: 1

   commands
   directives
   util
